The Mallgroup library is a collection of utilities.

Utilities:  
Heartbeat

Contact:  
dataengineering@mallgroup.com

Authors:  
Pressl Dan  
Urban Aemilia  
Hruban Jiří  
Juranková Sára

#Heartbeat
A class that is used to check the activity and healthiness of an application
by checking for the time between last and current timestamp.

#MongoDBDAO
A class that is used for connecting to the MongoDB
packed with utilities to work with the documents.

#RedisDAO
A class that is used for connecting to a Redis Cluster or Sentinels
allowing for a simpler interface above Redis client.